@@ -34,7 +34,7 @@ class Optimization:
 		data_end_filtre = [end for end in data_end if not isinstance(end,str)]
 		data_end_text = [end for end in data_end if isinstance(end,str)]
 		with localconverter(robjects.default_converter + pandas2ri.converter + numpy2ri.converter):
-			data_r_end =  robjects.conversion.py2rpy(data_end_filtre)
+			data_r_end =  robjects.vectors.FloatVector(data_end_filtre)
 			data_r_text_end =  robjects.conversion.py2rpy(data_end_text)
 		return (data_r_end,data_r_text_end)
      
